@@ -9,7 +9,7 @@ use base qw( Exporter );
 our @EXPORT = qw( find_lib assert_lib check_lib check_lib_or_exit find_lib_or_exit find_lib_or_die );
 
 # ABSTRACT: Check that a library is available for FFI
-our $VERSION = '0.08'; # VERSION
+our $VERSION = '0.09'; # VERSION
 
 
 our $system_path;
@@ -43,7 +43,7 @@ elsif($os eq 'MSWin32')
 }
 elsif($os eq 'darwin')
 {
-  push @$pattern, qr{^lib(.*?)\.(?:dylib|bundle)$};
+  push @$pattern, qr{^lib(.*?)(?:-[0-9\.]+)?\.(?:dylib|bundle)$};
 }
 
 sub _matches
@@ -82,7 +82,7 @@ sub find_lib
   
   my %missing = map { $_ => 1 } @{ $args{lib} };
   my %symbols = map { $_ => 1 } @{ $args{symbol} };
-  my @path = (@{ $args{libpath} }, @$system_path);
+  my @path = (@{ $args{libpath} }, (grep { defined } @$system_path));
   my @found;
 
   foreach my $path (@path)
@@ -217,7 +217,7 @@ FFI::CheckLib - Check that a library is available for FFI
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 SYNOPSIS
 
@@ -347,7 +347,11 @@ L<Dist::Zilla> plugin for this module.
 
 =head1 AUTHOR
 
-Graham Ollis <plicease@cpan.org>
+Author: Graham Ollis E<lt>plicease@cpan.orgE<gt>
+
+Contributors:
+
+Bakkiaraj Murugesan (bakkiaraj)
 
 =head1 COPYRIGHT AND LICENSE
 
